from __future__ import annotations

from abaqus.CustomKernel.CommandRegister import CommandRegister
from abaqus.CustomKernel.RegisteredDictionary import RegisteredDictionary
from abaqus.CustomKernel.RegisteredList import RegisteredList
from abaqus.CustomKernel.RegisteredTuple import RegisteredTuple
from abaqus.CustomKernel.RepositorySupport import RepositorySupport

__all__ = [
    "CommandRegister",
    "RegisteredDictionary",
    "RegisteredList",
    "RegisteredTuple",
    "RepositorySupport",
]



from __future__ import annotations

from typing import Any

from .AFXDataComponent import AFXDataComponent
from .constants import DEFAULT_PAD
from .FXComposite import FXComposite
from .FXFont import FXFont
from .FXIcon import FXIcon
from .FXObject import FXObject
from .FXPacker import FXPacker

#: Orient label above list box.
AFXLISTBOX_VERTICAL: int = hash("AFXLISTBOX_VERTICAL")

#: Configure list box to the read-only state.
AFXLISTBOX_READONLY: int = hash("AFXLISTBOX_READONLY")


class AFXListBox(FXPacker, AFXDataComponent):
    """This class implements a labeled list box.

    It allows the user to select entries from a drop-down list. Each item has associated data set as
    integers initially as items are added.
    """

    #: ID for the list box.
    ID_LIST: int = hash("ID_LIST")

    #: ID for the text field.
    ID_FIELD: int = hash("ID_FIELD")

    def __init__(
        self,
        p: FXComposite,
        nvis: int,
        labelText: str,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_PAD,
        pr: int = DEFAULT_PAD,
        pt: int = DEFAULT_PAD,
        pb: int = DEFAULT_PAD,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        nvis : int
            Number of visible items.
        labelText : str
            Label string.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        pl : int
            Left padding (margin).
        pr : int
            Right padding (margin).
        pt : int
            Top padding (margin).
        pb : int
            Bottom padding (margin).
        """

    def appendItem(self, text: str, icon: FXIcon | None = None, sel: int = 0):
        """Adds an item to the end of the list.

        Parameters
        ----------
        text : str
            Text
        icon : FXIcon | None

        sel : int
            Icon Integer associated with this item
        """

    def clearItems(self):
        """Removes all items from the list."""

    def create(self):
        """Creates the list box.

        Reimplemented from FXComposite.
        """

    def disable(self):
        """Disables the list box.

        Reimplemented from FXWindow.
        """

    def enable(self):
        """Enables the list box.

        Reimplemented from FXWindow.
        """

    def getCurrentItem(self):
        """Returns the index of the current item."""

    def getHelpText(self):
        """Returns the status line help text."""

    def getItemData(self, index: int):
        """Returns the data for the specified item.

        Parameters
        ----------
        index : int
        """

    def getItemIndexForData(self, data: Any):
        """Returns the index of the first item with the associated data or -1 if not found.

        Parameters
        ----------
        data : Any
        """

    def getLabelFont(self):
        """Returns the label font."""

    def getLabelText(self):
        """Returns the label string."""

    def getNumItems(self):
        """Returns the number of items in the list."""

    def getNumVisible(self):
        """Returns the number of visible items."""

    def getTipText(self):
        """Returns the tool tip message."""

    def insertItem(self, index: int, text: str, icon: FXIcon | None = None, sel: int = 0):
        """Inserts a new item at the specified index position.

        Parameters
        ----------
        index : int
            Index
        text : str
            Text
        icon : FXIcon | None
            Icon
        sel : int
            Integer associated with this item
        """

    def isItemCurrent(self, index: int):
        """Returns True if the item at the specified index position is the current item.

        Parameters
        ----------
        index : int
        """

    def isReadOnlyState(self):
        """Returns True if the list box is set to the read-only state."""

    def removeItem(self, index: int):
        """Removes the item at the specified index position from the list.

        Parameters
        ----------
        index : int
        """

    def replaceItem(self, index: int, text: str, icon: FXIcon | None = None, sel: int = 0):
        """Replaces the item at the specified index position.

        Parameters
        ----------
        index : int
            Index
        text : str
            Text
        icon : FXIcon | None
            Icon
        sel : int
            Integer associated with this item
        """

    def setCurrentItem(self, index: int, notify: bool = False):
        """Sets the current item. (The index is zero-based).

        Parameters
        ----------
        index : int

        notify : bool
        """

    def setHelpText(self, text: str):
        """Sets the status line help text.

        Parameters
        ----------
        text : str
        """

    def setItemData(self, index: int, ptr: str):
        """Sets the data for the specified item.

        Parameters
        ----------
        index : int

        ptr : str
        """

    def setLabelFont(self, fnt: FXFont):
        """Sets the label font.

        Parameters
        ----------
        fnt : FXFont
        """

    def setLabelText(self, txt: str):
        """Sets the label string.

        Parameters
        ----------
        txt : str
        """

    def setNumVisible(self, nvis: int):
        """Sets the number of visible items.

        Parameters
        ----------
        nvis : int
        """

    def setReadOnlyState(self, readonly: bool = True):
        """Sets the read-only state of the list box.

        Parameters
        ----------
        readonly : bool
        """

    def setTipText(self, text: str):
        """Sets the tool tip message.

        Parameters
        ----------
        text : str
        """



from __future__ import annotations

from .AFXGuiObjectManager import AFXGuiObjectManager


class AFXModuleGui(AFXGuiObjectManager):
    """This is the base class for module GUIs and provides an interface for module GUI management."""

    #: Displays a part primary object.
    PART: int = hash("PART")

    #: Displays an assembly primary object.
    ASSEMBLY: int = hash("ASSEMBLY")

    #: Displays an ODB primary object.
    ODB: int = hash("ODB")

    #: Displays an XY plot primary object.
    XY_PLOT: int = hash("XY_PLOT")

    #: Displays a sketch primary object.
    SKETCH: int = hash("SKETCH")

    def __init__(self, moduleName: str, displayTypes: int):
        """Constructor.

        Parameters
        ----------
        moduleName : str
            Name used to identify this module.
        displayTypes : int
            Types of primary objects that this module may display.
        """

    def activate(self):
        """Activates the module during switch processing (allows for module specific activation
        requirements)."""

    def deactivate(self):
        """Deactivates the module when switching out (allows for module specific deactivation requirements)."""

    def getModuleName(self):
        """Returns the name of the module given on construction."""

    def getTypesToDisplay(self):
        """Returns the type of the primary objects which may be displayed when this module is active (this
        currently assumes a single type)."""

    def hide(self, location: int):
        """Deactivates and hides the module's GUI components in the menubar, toolbar and toolbox.

        Parameters
        ----------
        location : int
            Location where gui components are placed.
        """

    def show(self, location: int):
        """Activates and shows the module's GUI components in the menubar, toolbar and toolbox.

        Parameters
        ----------
        location : int
            Location where gui components are placed.
        """



from __future__ import annotations

from .AFXCommand import AFXCommand
from .AFXKeyword import AFXKeyword


class AFXBoolKeyword(AFXKeyword):
    """This class is designed for command keywords that have Boolean values."""

    #: Keyword value will be ON or OFF.
    ON_OFF: int = hash("ON_OFF")

    #: Keyword value will be True or False.
    TRUE_FALSE: int = hash("TRUE_FALSE")

    def __init__(
        self,
        command: AFXCommand,
        name: str,
        booleanType=ON_OFF,
        isRequired: bool = False,
        defaultValue: bool = False,
    ):
        """Constructor.

        Parameters
        ----------
        command : AFXCommand
            Host command.
        name : str
            Keyword name.
        booleanType : Type
            Type of boolean used in the command.
        isRequired : bool
            True if the keyword is a required argument of the command.
        defaultValue : bool
            Default value.
        """

    def getTypeName(self):
        """Returns the name of the keyword type.

        Implements AFXKeyword.
        """

    def getValue(self):
        """Returns the keyword's current value."""

    def getValueAsString(self):
        """Returns the text string that represents the keyword's current value.

        Implements AFXKeyword.
        """

    def isValueChanged(self):
        """Returns True if the keyword value differs from its previous value.

        Implements AFXKeyword.
        """

    def setDefaultValue(self, defaultValue: bool):
        """Sets the keyword's default value.

        Parameters
        ----------
        defaultValue : bool
            Default value.
        """

    def setDefaultValueByString(self, defaultValueString: str):
        """Sets the keyword's default value (returns True if the given text string is valid).

        Parameters
        ----------
        defaultValueString : str
            Default value in text string form.
        """

    def setValue(self, newValue: bool):
        """Sets the keyword's current value.

        Parameters
        ----------
        newValue : bool
            New value.
        """

    def setValueByString(self, newValueString: str):
        """Sets the keyword's current value (returns True if the given text string is valid).

        Parameters
        ----------
        newValueString : str
            New value in text string form.
        """

    def setValueToDefault(self, ignoreUnspecified: bool = False):
        """Sets the keyword value to its default.

        Parameters
        ----------
        ignoreUnspecified : bool
            Not used.
        """

    def setValueToPrevious(self):
        """Sets the keyword value to its previous value.

        Implements AFXKeyword.
        """

    def syncPreviousValue(self):
        """Sets the keyword's previous value to its current value.

        Implements AFXKeyword.
        """



from __future__ import annotations

from typing import TYPE_CHECKING, List, Sequence, Union

from abaqus.BasicGeometry.Edge import Edge
from abaqus.BasicGeometry.Face import Face
from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .MeshElement import MeshElement

if TYPE_CHECKING:  # to avoid circular imports
    from ..BasicGeometry.EdgeArray import EdgeArray
    from ..BasicGeometry.FaceArray import FaceArray


@abaqus_class_doc
class MeshElementArray(List[MeshElement]):
    """The MeshElementArray is a sequence of MeshElement objects.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].allInternalSets[name].elements
            mdb.models[name].parts[name].allInternalSurfaces[name].elements
            mdb.models[name].parts[name].allSets[name].elements
            mdb.models[name].parts[name].allSurfaces[name].elements
            mdb.models[name].parts[name].elements
            mdb.models[name].parts[name].sets[name].elements
            mdb.models[name].parts[name].surfaces[name].elements
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].elements
            mdb.models[name].rootAssembly.allInstances[name].sets[name].elements
            mdb.models[name].rootAssembly.allInstances[name].surfaces[name].elements
            mdb.models[name].rootAssembly.allInternalSets[name].elements
            mdb.models[name].rootAssembly.allInternalSurfaces[name].elements
            mdb.models[name].rootAssembly.allSets[name].elements
            mdb.models[name].rootAssembly.allSurfaces[name].elements
            mdb.models[name].rootAssembly.elements
            mdb.models[name].rootAssembly.instances[name].elements
            mdb.models[name].rootAssembly.instances[name].sets[name].elements
            mdb.models[name].rootAssembly.instances[name].surfaces[name].elements
            mdb.models[name].rootAssembly.modelInstances[i].elements
            mdb.models[name].rootAssembly.modelInstances[i].sets[name].elements
            mdb.models[name].rootAssembly.modelInstances[i].surfaces[name].elements
            mdb.models[name].rootAssembly.sets[name].elements
            mdb.models[name].rootAssembly.surfaces[name].elements
    """

    @abaqus_method_doc
    def __init__(self, elements: list[MeshElement]) -> None:
        """This method creates a MeshElementArray object.

        .. note::
            This function can be accessed by::

                mesh.MeshElementArray

        Parameters
        ----------
        elements
            A list of MeshElement objects.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object.
        """
        super().__init__()

    @abaqus_method_doc
    def getFromLabel(self, label: int) -> MeshElement:
        """This method returns the object in the MeshElementArray with the given label.

        Parameters
        ----------
        label
            An Int specifying the label of the object.

        Returns
        -------
        MeshElement
            A MeshElement object.
        """
        return MeshElement()

    @abaqus_method_doc
    def getSequenceFromMask(self, mask: Union[str, Sequence[str]]) -> MeshElementArray:
        """This method returns the objects in the MeshElementArray identified using the specified
        **mask**. This command is generated when the JournalOptions are set to COMPRESSEDINDEX.
        When a large number of objects are involved, this method is highly efficient.

        Parameters
        ----------
        mask
            A String specifying the object or objects.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object.
        """
        return MeshElementArray([MeshElement()])

    @abaqus_method_doc
    def getMask(self) -> str:
        """This method returns a string specifying the object or objects.

        Returns
        -------
        str
            A String specifying the object or objects.
        """
        return ""

    @abaqus_method_doc
    def getByBoundingBox(
        self,
        xMin: float = 0,
        yMin: float = 0,
        zMin: float = 0,
        xMax: float = 0,
        yMax: float = 0,
        zMax: float = 0,
    ) -> MeshElementArray:
        """This method returns an array of element objects that lie within the specified bounding box.

        Parameters
        ----------
        xMin
            A float specifying the minimum X boundary of the bounding box.
        yMin
            A float specifying the minimum Y boundary of the bounding box.
        zMin
            A float specifying the minimum Z boundary of the bounding box.
        xMax
            A float specifying the maximum X boundary of the bounding box.
        yMax
            A float specifying the maximum Y boundary of the bounding box.
        zMax
            A float specifying the maximum Z boundary of the bounding box.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object, which is a sequence of MeshElement objects.
        """
        return MeshElementArray([MeshElement()])

    @abaqus_method_doc
    def getByBoundingCylinder(self, center1: tuple, center2: tuple, radius: str) -> MeshElementArray:
        """This method returns an array of element objects that lie within the specified bounding cylinder.

        Parameters
        ----------
        center1
            A tuple of the X-, Y-, and Z-coordinates of the center of the first end of the cylinder.
        center2
            A tuple of the X-, Y-, and Z-coordinates of the center of the second end of the
            cylinder.
        radius
            A float specifying the radius of the cylinder.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object, which is a sequence of MeshElement objects.
        """
        return MeshElementArray([MeshElement()])

    @abaqus_method_doc
    def getByBoundingSphere(self, center: tuple[float, float, float], radius: float) -> MeshElementArray:
        """This method returns an array of element objects that lie within the specified bounding sphere.

        Parameters
        ----------
        center
            A tuple of the X-, Y-, and Z-coordinates of the center of the sphere.
        radius
            A float specifying the radius of the sphere.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object, which is a sequence of MeshElement objects.
        """
        return MeshElementArray([MeshElement()])

    @abaqus_method_doc
    def getBoundingBox(self) -> dict[str, tuple[float, float, float]]:
        """This method returns a dictionary of two tuples representing minimum and maximum boundary values of
        the bounding box of the minimum size containing the element sequence.

        Returns
        -------
        dict[str, tuple[float, float, float]]
            A Dictionary object with the following items:

            - **low**: a tuple of three floats representing the minimum x, y, and z boundary values of
              the bounding box.
            - **high**: a tuple of three floats representing the maximum x, y, and z boundary values of
              the bounding box.
        """
        return {"low": (0.0, 0.0, 0.0), "high": (0.0, 0.0, 0.0)}

    @abaqus_method_doc
    def sequenceFromLabels(self, labels: Sequence[int]) -> MeshElementArray:
        """This method returns the objects in the MeshElementArray identified using the specified labels.

        Parameters
        ----------
        labels
            A sequence of Ints specifying the labels.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object.

        Raises
        ------
        Error
            The mask results in an empty sequence, An exception occurs if the resulting sequence is empty.
        """
        return MeshElementArray([MeshElement()])

    @abaqus_method_doc
    def getExteriorEdges(self) -> EdgeArray:
        """This method returns the edges on the exterior of the faces in the FaceArray. That is, it returns the
        edges that are referenced by exactly one of the faces in the sequence.

        .. versionadded:: 2018
            The ``getExteriorEdges`` method was added.

        Returns
        -------
        EdgeArray
            An EdgeArray object specifying the exterior edges.
        """
        return EdgeArray([Edge()])

    @abaqus_method_doc
    def getExteriorFaces(self) -> FaceArray:
        """This method returns the cell faces on the exterior of the CellArray. That is, it returns the faces
        that are referenced by exactly one of the cells in the sequence.

        .. versionadded:: 2018
            The ``getExteriorFaces`` method was added.

        Returns
        -------
        FaceArray
            A FaceArray object representing the faces on the exterior of the cells.
        """
        return FaceArray([Face()])



from __future__ import annotations

from .constants import DEFAULT_PAD
from .FXComposite import FXComposite
from .FXLabel import FXLabel
from .FXObject import FXObject

#: Automatically gray out when not updated.
CHECKBUTTON_AUTOGRAY: int = hash("CHECKBUTTON_AUTOGRAY")

#: Automatically hide when not updated.
CHECKBUTTON_AUTOHIDE: int = hash("CHECKBUTTON_AUTOHIDE")

#: Normal check button.
CHECKBUTTON_NORMAL: int = hash("CHECKBUTTON_NORMAL")


class FXCheckButton(FXLabel):
    """A check button is a tri-state button.

    Normally, it is either True or False, and toggles between True or False whenever it is pressed. A third
    state MAYBE may be set to indicate that no selection has been made yet by the user, or that the state is
    ambiguous. When pressed, the check button sends a SEL_COMMAND to its target, and the message data
    represents the state of the check button.
    """

    def __init__(
        self,
        p: FXComposite,
        text: str,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = CHECKBUTTON_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_PAD,
        pr: int = DEFAULT_PAD,
        pt: int = DEFAULT_PAD,
        pb: int = DEFAULT_PAD,
    ):
        """Construct new check button.

        Parameters
        ----------
        p : FXComposite

        text : str

        tgt : FXObject | None

        sel : int

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int
        """

    def canFocus(self):
        """Returns True because a check button can receive focus.

        Reimplemented from FXWindow.
        """

    def getCheck(self):
        """Get check button state (True, False or MAYBE).

        Reimplemented in AFXCheckButton.
        """

    def getDefaultHeight(self):
        """Get default height.

        Reimplemented from FXLabel.
        """

    def getDefaultWidth(self):
        """Get default width.

        Reimplemented from FXLabel.
        """

    def setCheck(self, state: bool = True):
        """Set check button state (True, False or MAYBE).

        Parameters
        ----------
        state : bool
        """



from __future__ import annotations

from .FXApp import FXApp
from .FXComposite import FXComposite
from .FXDialogBox import FXDialogBox
from .FXIcon import FXIcon
from .FXObject import FXObject
from .FXWindow import FXWindow

#: Creates the action area horizontally at the bottom of the dialog box.
DIALOG_ACTIONS_BOTTOM: int = hash("DIALOG_ACTIONS_BOTTOM")

#: Creates the action area vertically at the right side of the dialog box.
DIALOG_ACTIONS_RIGHT: int = hash("DIALOG_ACTIONS_RIGHT")

#: Do not create the action area.
DIALOG_ACTIONS_NONE: int = hash("DIALOG_ACTIONS_NONE")

#: Creates a separator in the action area.
DIALOG_ACTIONS_SEPARATOR: int = hash("DIALOG_ACTIONS_SEPARATOR")

#: Deletes the dialog box when unposted.
DIALOG_UNPOST_DELETE: int = hash("DIALOG_UNPOST_DELETE")

#: Destroys the dialog box when unposted.
DIALOG_UNPOST_DESTROY: int = hash("DIALOG_UNPOST_DESTROY")

#: Do nothing when unposted.
DIALOG_UNPOST_NOTHING: int = hash("DIALOG_UNPOST_NOTHING")

#: Default dialog box options.
DIALOG_NORMAL: int = hash("DIALOG_NORMAL")


class AFXDialog(FXDialogBox):
    """AFXDialog."""

    #: OK button ID.
    ID_CLICKED_OK: int = hash("ID_CLICKED_OK")

    #: Contiue button ID.
    ID_CLICKED_CONTINUE: int = hash("ID_CLICKED_CONTINUE")

    #: Yes button ID.
    ID_CLICKED_YES: int = hash("ID_CLICKED_YES")

    #: Yes to All button ID.
    ID_CLICKED_YES_TO_ALL: int = hash("ID_CLICKED_YES_TO_ALL")

    #: Apply button ID.
    ID_CLICKED_APPLY: int = hash("ID_CLICKED_APPLY")

    #: Defaults button ID.
    ID_CLICKED_DEFAULTS: int = hash("ID_CLICKED_DEFAULTS")

    #: No button ID.
    ID_CLICKED_NO: int = hash("ID_CLICKED_NO")

    #: Cacncel button ID.
    ID_CLICKED_CANCEL: int = hash("ID_CLICKED_CANCEL")

    #: Dismiss button ID.
    ID_CLICKED_DISMISS: int = hash("ID_CLICKED_DISMISS")

    #: Adds an Apply button to action area.
    APPLY: int = hash("APPLY")

    #: Adds a Cancel button to action area.
    CANCEL: int = hash("CANCEL")

    #: Adds a Continue button to action area.
    CONTINUE: int = hash("CONTINUE")

    #: Adds a Defaults button to action area.
    DEFAULTS: int = hash("DEFAULTS")

    #: Adds a Dismiss button to action area.
    DISMISS: int = hash("DISMISS")

    #: Adds a No button to action area.
    NO: int = hash("NO")

    #: Adds an OK button to action area.
    OK: int = hash("OK")

    #: Adds a Yes button to action area.
    YES: int = hash("YES")

    #: Adds a Yes to All button to action area.
    YES_TO_ALL: int = hash("YES_TO_ALL")

    def __init__(
        self,
        app: FXApp,
        title: str,
        actionButtonIds: int = 0,
        opts: int = DIALOG_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
    ):
        """Constructor that creates a dialog box that may be occluded by any other windows of the application.

        Parameters
        ----------
        app : FXApp
            Application.
        title : str
            Title string.
        actionButtonIds : int
            ID's of action buttons to be created.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        """

    def appendActionButton(self, buttonID):
        """Adds a standard action button in the action area of the dialog box.

        Parameters
        ----------
        buttonID : ButtonID
            Button ID.
        """

    def bailout(self):
        """Performs checks to determine whether it is OK to cancel the dialog box.

        The implementaton of this class always returns True, and the derived class should reimplement this
        method to perform specific checks. Reimplemented in AFXDataDialog.
        """

    def create(self):
        """Creates the dialog box.

        Reimplemented from FXTopWindow.
        """

    def createButton(self, parent: FXComposite, text: str, icon: FXIcon, tgt: FXObject, sel: int, opts: int):
        """Creates an action area button.

        Parameters
        ----------
        parent : FXComposite
            Parent widget.
        text : str
            Label string.
        icon : FXIcon
            Icon.
        tgt : FXObject
            Message target.
        sel : int
            Message ID.
        opts : int
            Options and hints.
        """

    def getActionButton(self, sel: int):
        """Returns the action button with the specified message ID; returns 0 if none of the action buttons has
        the message ID.

        Parameters
        ----------
        sel : int
            Message ID.
        """

    def getUnpostHints(self):
        """Returns the action that the poster should perform on this dialog box when it is unposted.

        Possible return values are: DIALOG_UNPOST_DELETE - delete the C++ dialog box object together with the associated window. (default) DIALOG_UNPOST_DESTROY - keep the C++ dialog box object, but destroy the associated window to release resources. DIALOG_UNPOST_NOTHING - do nothing.
        """

    def hide(self):
        """Unpost the dialog box.

        Reimplemented from FXTopWindow. Reimplemented in AFXManagerMenuDB, and AFXMessageDialog.
        """

    def onKeywordError(self, kwd: FXObject):
        """Handles the error that occurs when the given keyword or target contains invalid contents. This method
        will select the contents of the widget that has the keyword or target as its message target.

        Parameters
        ----------
        kwd : FXObject
            Object that contains invalid contents.
        """

    def onTableError(self, tableKwd: FXObject, row: int, col: int):
        """Handles the error that occurs when the given table keyword or target contains an invalid element.
        This method will select the contents of the widget that has the keyword or target as its message target.

        Parameters
        ----------
        tableKwd : FXObject
            Object that contains invalid element.
        row : int
            Row index.
        col : int
            Column index.
        """

    def onTupleError(self, tupleKwd: FXObject, index: int):
        """Handles the error that occurs when the given tuple keyword or target contains an invalid element.
        This method will select the contents of the widget that has the keyword or target as its message target.

        Parameters
        ----------
        tupleKwd : FXObject
            Object that contains invalid element.
        index : int
            Element index.
        """

    def selectContents(self, widget: FXWindow):
        """Selects the contents of the given widget.

        Parameters
        ----------
        widget : FXWindow
            Widget to select.
        """

    def selectTableElement(self, widget: FXWindow, row: int, col: int):
        """Selects the given (row,col) element in the 2D array of elements displayed by the given widget.

        Parameters
        ----------
        widget : FXWindow
            Widget to select.
        row : int
            Row index.
        col : int
            Column index.
        """

    def selectTupleElement(self, widget: FXWindow, index: int):
        """Selects the element at the given index in the sequence of elements displayed by the given widget.

        Parameters
        ----------
        widget : FXWindow
            Widget to select.
        index : int
            Element index.
        """

    def setOnPopdownTarget(self, target: FXObject):
        """Sets the object to be notified when the dialog box is unposted.

        Parameters
        ----------
        target : FXObject
            Object to be notified when the dialog box is unposted.
        """

    def setUnpostHints(self, hints: int):
        """Sets the action that the poster should perform on this dialog box when it is unposted.

        Parameters
        ----------
        hints : int
        """

    def show(self):
        """Posts the dialog box.

        Reimplemented from FXTopWindow. Reimplemented in AFXFileDialog, and AFXMessageDialog.
        """

    def showModal(self, occludedWindow: FXWindow | None = None):
        """Posts the dialog box as a modal dialog box. The dialog box is centered against the given widget or
        its owner widget if 0 is given.

        Parameters
        ----------
        occludedWindow : FXWindow | None
            Widget to be occluded (0 for the owner widget).
        """



from __future__ import annotations

from .FXObject import FXObject

#: Extended selection mode allows for drag-selection of ranges of items.
LIST_EXTENDEDSELECT: int = hash("LIST_EXTENDEDSELECT")

#: Single selection mode allows up to one item to be selected.
LIST_SINGLESELECT: int = hash("LIST_SINGLESELECT")

#: Browse selection mode enforces one single item to be selected at all times.
LIST_BROWSESELECT: int = hash("LIST_BROWSESELECT")

#: Multiple selection mode is used for selection of individual items.
LIST_MULTIPLESELECT: int = hash("LIST_MULTIPLESELECT")

#: Automatically select under cursor.
LIST_AUTOSELECT: int = hash("LIST_AUTOSELECT")


class FXListItem(FXObject):
    """List item."""



from __future__ import annotations

from .constants import DEFAULT_SPACING
from .FXColor import FXColor
from .FXComposite import FXComposite


class FXPacker(FXComposite):
    """Packer is a layout manager which automatically places child windows inside its area against the left,
    right, top, or bottom side.

    Each time a child is placed, the remaining space is decreased by the amount of space taken by the child
    window. The side against which a child is placed is determined by the LAYOUT_SIDE_TOP,
    LAYOUT_SIDE_BOTTOM, LAYOUT_SIDE_LEFT, and LAYOUT_SIDE_RIGHT hints given by the child window. Other
    layout hints from the child are observed as far as sensible. So for example, a child placed against the
    right edge can still have LAYOUT_FILL_Y or LAYOUT_TOP, and so on. The last child may have both
    LAYOUT_FILL_X and LAYOUT_FILL_Y, in which case it will be placed to take all remaining space.
    """

    def __init__(
        self,
        p: FXComposite,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
        hs: int = DEFAULT_SPACING,
        vs: int = DEFAULT_SPACING,
    ):
        """Construct packer layout manager.

        Parameters
        ----------
        p : FXComposite

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int

        hs : int

        vs : int
        """

    def getBaseColor(self):
        """Get base gui color."""

    def getBorderColor(self):
        """Get border color."""

    def getBorderWidth(self):
        """Get border width."""

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXComposite. Reimplemented in FXComboBox, FXDockSite, FXGroupBox,
        FXHorizontalFrame, FXListBox, FXMatrix, FXSpinner, FXStatusbar, FXSwitcher, FXTabBar, FXTabBook,
        FXToolbar, FXTreeListBox, FXVerticalFrame, AFXToolbarGroup, AFXPrimFloatSpinner, AFXSlider, and
        AFXVerticalAligner.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXComposite. Reimplemented in FXComboBox, FXDockSite, FXGroupBox,
        FXHorizontalFrame, FXListBox, FXMatrix, FXSpinner, FXStatusbar, FXSwitcher, FXTabBar, FXTabBook,
        FXToolbar, FXTreeListBox, FXVerticalFrame, AFXToolbarGroup, AFXOptionTreeItem, AFXPrimFloatSpinner,
        AFXSlider, AFXTextField, and AFXVerticalAligner.
        """

    def getFrameStyle(self):
        """Get current frame style."""

    def getHiliteColor(self):
        """Get highlight color."""

    def getHSpacing(self):
        """Return current horizontal inter-child spacing."""

    def getPackingHints(self):
        """Return packing hints."""

    def getPadBottom(self):
        """Get bottom interior padding."""

    def getPadLeft(self):
        """Get left interior padding."""

    def getPadRight(self):
        """Get right interior padding."""

    def getPadTop(self):
        """Get top interior padding."""

    def getShadowColor(self):
        """Get shadow color."""

    def getVSpacing(self):
        """Return current vertical inter-child spacing."""

    def setBaseColor(self, clr: FXColor):
        """Change base gui color.

        Parameters
        ----------
        clr : FXColor
        """

    def setBorderColor(self, clr: FXColor):
        """Change border color.

        Parameters
        ----------
        clr : FXColor
        """

    def setFrameStyle(self, style: int):
        """Change frame style.

        Parameters
        ----------
        style : int
        """

    def setHiliteColor(self, clr: FXColor):
        """Change highlight color.

        Parameters
        ----------
        clr : FXColor
        """

    def setHSpacing(self, hs: int):
        """Change horizontal inter-child spacing.

        Parameters
        ----------
        hs : int
        """

    def setPackingHints(self, ph: int):
        """Change packing hints.

        Parameters
        ----------
        ph : int
        """

    def setPadBottom(self, pb: int):
        """Change bottom padding.

        Parameters
        ----------
        pb : int
        """

    def setPadLeft(self, pl: int):
        """Change left padding.

        Parameters
        ----------
        pl : int
        """

    def setPadRight(self, pr: int):
        """Change right padding.

        Parameters
        ----------
        pr : int
        """

    def setPadTop(self, pt: int):
        """Change top padding.

        Parameters
        ----------
        pt : int
        """

    def setShadowColor(self, clr: FXColor):
        """Change shadow color.

        Parameters
        ----------
        clr : FXColor
        """

    def setVSpacing(self, vs: int):
        """Change vertical inter-child spacing.

        Parameters
        ----------
        vs : int
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class Keyword:
    """The Keyword object is used to store a keyword definition from an Abaqus input file. Keyword objects are
    returned via the InputFile.parse() method.

    .. note::
        This object can be accessed by::

            import inpParser
    """

    #: A String specifying the name of the keyword.
    name: str = ""

    #: A Dictionary of Strings specifying the keyword parameters.
    parameter: dict | None = None

    #: A sequence of sequences or an AbaqusNDarray object specifying the keyword data. The type
    #: of the leaf objects depends on the keyword. The AbaqusNDarray object is returned only if
    #: the data is suitable and if the InputFile.parse() method was called with the option
    #: usePyArray=True. In cases where large amounts of numerical data (i.e., large node
    #: arrays) are expected, it is recommended that you use the option usePyArray=True.
    data: tuple = ()

    #: A KeywordSequence specifying the suboptions of the keyword.
    suboptions: str = ""

    #: A sequence of Strings specifying the comments.
    comments: tuple = ()



from __future__ import annotations

from .FXColor import FXColor
from .FXShell import FXShell
from .FXWindow import FXWindow

#: Vertical orientation.
POPUP_VERTICAL: int = hash("POPUP_VERTICAL")

#: Horizontal orientation.
POPUP_HORIZONTAL: int = hash("POPUP_HORIZONTAL")

#: Shrinkwrap to content.
POPUP_SHRINKWRAP: int = hash("POPUP_SHRINKWRAP")


class FXPopup(FXShell):
    """Popup window."""

    def __init__(self, owner: FXWindow, x: int = 0, y: int = 0, w: int = 0, h: int = 0):
        """Construct popup pane.

        Parameters
        ----------
        owner : FXWindow

        x : int

        y : int

        w : int

        h : int
        """

    def getBaseColor(self):
        """Return base color."""

    def getBorderColor(self):
        """Return border color."""

    def getBorderWidth(self):
        """Return border width."""

    def getDefaultHeight(self):
        """Return the default height of this window.

        Reimplemented from FXComposite.
        """

    def getDefaultWidth(self):
        """Return the default width of this window.

        Reimplemented from FXComposite.
        """

    def getFrameStyle(self):
        """Return frame style."""

    def getGrabOwner(self):
        """Return current grab owner."""

    def getHiliteColor(self):
        """Return highlight color."""

    def getOrientation(self):
        """Return popup orientation."""

    def getShadowColor(self):
        """Return shadow color."""

    def getShrinkWrap(self):
        """Return shrinkwrap mode."""

    def popdown(self):
        """Pop down the menu."""

    def popup(self, grabto: FXWindow, x: int, y: int, w: int = 0, h: int = 0):
        """Popup the menu and grab to the given owner.

        Parameters
        ----------
        grabto : FXWindow

        x : int

        y : int

        w : int

        h : int
        """

    def setBaseColor(self, clr: FXColor):
        """Change base color.

        Parameters
        ----------
        clr : FXColor
        """

    def setBorderColor(self, clr: FXColor):
        """Change border color.

        Parameters
        ----------
        clr : FXColor
        """

    def setFrameStyle(self, style: int):
        """Change frame style.

        Parameters
        ----------
        style : int
        """

    def setHiliteColor(self, clr: FXColor):
        """Change highlight color.

        Parameters
        ----------
        clr : FXColor
        """

    def setOrientation(self, orient: int):
        """Change popup orientation.

        Parameters
        ----------
        orient : int
        """

    def setShadowColor(self, clr: FXColor):
        """Change shadow color.

        Parameters
        ----------
        clr : FXColor
        """

    def setShrinkWrap(self, sw: bool):
        """Change shrinkwrap mode.

        Parameters
        ----------
        sw : bool
        """
